@@ -16,78 +16,19 @@ import logging
 import os.path
 import yaml
 
-import sphinx.builders
+from multiprocessing import cpu_count
 
 logger = logging.getLogger('giza.config.runtime')
 
 from giza.command import CommandError
 
 from giza.config.base import ConfigurationBase
+from giza.config.sphinx_config import avalible_sphinx_builders
 
-class RuntimeStateConfig(ConfigurationBase):
-    _option_registry = [ 'length', 'days_to_save', 'builder_to_delete',
-                         'git_branch', 'git_sign_patch', 'serial_sphinx',
-                         'clean_generated', 'include_mask', 'push_targets', 'dry_run' ]
-
+class RuntimeStateConfigurationBase(ConfigurationBase):
     def __init__(self, obj=None):
-        super(RuntimeStateConfig, self).__init__(obj)
+        super(RuntimeStateConfigurationBase, self).__init__(obj)
         self._conf = None
-        self._branch_conf = None
-
-    @property
-    def function(self):
-        return self.state['_entry_point']
-
-    @function.setter
-    def function(self, value):
-        self.state['_entry_point'] = value
-
-    @property
-    def conf_path(self):
-        if 'conf_path' not in self.state:
-            self.conf_path = None
-
-        return self.state['conf_path']
-
-    @conf_path.setter
-    def conf_path(self, value):
-        if value is not None and os.path.exists(value):
-            self.state['conf_path'] = value
-        else:
-            conf_file_name = 'build_conf.yaml'
-
-            cur = os.path.abspath(os.getcwd())
-            if 'config' in os.listdir(cur):
-                fq_conf_file = os.path.join(cur, 'config', conf_file_name)
-                if os.path.exists(fq_conf_file):
-                    self.state['conf_path'] = fq_conf_file
-                else:
-                    m = '"{0}" file does not exist'.format(fq_conf_file)
-                    logger.error(m)
-                    raise OSError(m)
-            else:
-                self.state['conf_path'] = None
-
-                cur = cur.split(os.path.sep)
-                for i in range(len(cur)):
-                    current_attempt = os.path.sep + os.path.join(*cur[:len(cur) - i])
-
-                    contents = os.listdir(current_attempt)
-
-                    if conf_file_name in contents:
-                        fq_conf_file = os.path.join(current_attempt, conf_file_name)
-                        self.state['conf_path'] = fq_conf_file
-                        break
-                    elif 'config' in contents:
-                        fq_conf_file = os.path.join(current_attempt, 'config', conf_file_name)
-                        if os.path.exists(fq_conf_file):
-                            self.state['conf_path'] = fq_conf_file
-                            break
-
-                if self.state['conf_path'] is None:
-                    m = 'cannot locate config file'
-                    logger.error(m)
-                    raise OSError(m)
 
     @property
     def conf(self):
@@ -102,6 +43,42 @@ class RuntimeStateConfig(ConfigurationBase):
             m.error(m)
             raise TypeError(m)
 
+    @property
+    def function(self):
+        return self.state['_entry_point']
+
+    @function.setter
+    def function(self, value):
+        self.state['_entry_point'] = value
+
+    @property
+    def force(self):
+        if 'force' in self.state:
+            return self.state['force']
+        else:
+            return False
+
+    @force.setter
+    def force(self, value):
+        if isinstance(value, bool):
+            self.state['force'] = value
+        else:
+            raise TypeError
+
+    @property
+    def serial(self):
+        if 'serial' in self.state:
+            return self.state['serial']
+        else:
+            return False
+
+    @serial.setter
+    def serial(self, value):
+        if isinstance(value, bool):
+            self.state['serial'] = value
+        else:
+            raise TypeError
+
     @property
     def level(self):
         if 'level' not in self.state:
@@ -150,18 +127,83 @@ class RuntimeStateConfig(ConfigurationBase):
             raise TypeError(m)
 
     @property
-    def force(self):
-        if 'force' in self.state:
-            return self.state['force']
+    def pool_size(self):
+        if 'pool_size' not in self.state:
+            return cpu_count()
         else:
-            return False
+            return self.state['pool_size']
 
-    @force.setter
-    def force(self, value):
-        if isinstance(value, bool):
-            self.state['force'] = value
+    @pool_size.setter
+    def pool_size(self, value):
+        if value == 1:
+            self.serial = True
+        elif value <= 0:
+            raise TypeError('invalid pool size value: ' + value)
         else:
-            raise TypeError
+            self.state['pool_size'] = value
+
+    def _discover_conf_file(self, conf_file_name):
+        cur = os.path.abspath(os.getcwd())
+        home_path = os.path.expanduser(os.path.join('~', conf_file_name))
+
+        if 'conf_path' not in self.state:
+            self.state['conf_path'] = None
+
+        # first look for files in likely default places:
+        if 'config' in os.listdir(cur):
+            fq_conf_file = os.path.join(cur, 'config', conf_file_name)
+            if os.path.exists(fq_conf_file):
+                self.state['conf_path'] = fq_conf_file
+                return True
+        elif os.path.exists(home_path):
+             self.state['conf_path'] = home_path
+             return True
+
+        # now we'll try crawling up the directory tree to find the file
+        cur = cur.split(os.path.sep)
+        for i in range(len(cur)):
+            current_attempt = os.path.sep + os.path.join(*cur[:len(cur) - i])
+
+            contents = os.listdir(current_attempt)
+
+            if conf_file_name in contents:
+                fq_conf_file = os.path.join(current_attempt, conf_file_name)
+                self.state['conf_path'] = fq_conf_file
+                break
+            elif 'config' in contents:
+                fq_conf_file = os.path.join(current_attempt, 'config', conf_file_name)
+                if os.path.exists(fq_conf_file):
+                    self.state['conf_path'] = fq_conf_file
+                    break
+
+        # If we couldn't find a config file, throw an error.
+        if self.state['conf_path'] is None:
+            m = 'cannot locate config file'
+            logger.error(m)
+            raise OSError(m)
+
+class RuntimeStateConfig(RuntimeStateConfigurationBase):
+    _option_registry = [ 'serial', 'length', 'days_to_save', 'builder_to_delete',
+                         'git_branch', 'git_sign_patch', 'serial_sphinx', 'package_path',
+                         'clean_generated', 'include_mask', 'push_targets', 'dry_run' ]
+
+    def __init__(self, obj=None):
+        super(RuntimeStateConfig, self).__init__(obj)
+        self._branch_conf = None
+
+    @property
+    def conf_path(self):
+        if 'conf_path' not in self.state:
+            self.conf_path = None
+
+        return self.state['conf_path']
+
+    @conf_path.setter
+    def conf_path(self, value):
+        if value is not None and os.path.exists(value):
+            self.state['conf_path'] = value
+        else:
+            self._discover_conf_file('build_conf.yaml')
 
     @property
     def language(self):
@@ -177,7 +219,7 @@ class RuntimeStateConfig(ConfigurationBase):
     @property
     def edition(self):
         if 'edition' not in self.state:
-            return False
+            return None
         else:
             return self.state['edition']
 
@@ -225,7 +267,7 @@ class RuntimeStateConfig(ConfigurationBase):
                 builder = 'latex'
                 value[idx] = builder
 
-            if builder not in sphinx.builders.BUILTIN_BUILDERS:
+            if builder not in avalible_sphinx_builders():
                 raise TypeError("{0} is not a valid builder".format(builder))
 
         self.state['builder'] = value
