@@ -45,10 +45,29 @@ def render_sconf(edition, builder, language, conf):
 
     return sconf
 
+############### Helpers ###############
+
+def resolve_builder_path(builder, edition, language, conf):
+    dirname = builder
+
+    if edition is not None and edition != conf.project.name:
+        dirname = hyph_concat(dirname, edition)
+
+    if language is not None and language != 'en':
+        dirname = hyph_concat(dirname, language)
+
+    return os.path.join(conf.paths.projectroot, conf.paths.branch_output, dirname)
+
+def avalible_sphinx_builders():
+    builders = sphinx.builders.BUILTIN_BUILDERS.keys()
+    builders.append('slides')
+
+    return builders
+
 #################### New-Style Config Object ####################
 
 class SphinxConfig(RecursiveConfigurationBase):
-    _option_registry = [ 'edition', 'language', 'languages' ]
+    _option_registry = [ 'languages' ]
 
     def __init__(self, conf, input_obj=None):
         # register the global config, but use our ingestion
@@ -78,6 +97,8 @@ class SphinxConfig(RecursiveConfigurationBase):
         else:
             lookup = hyph_concat(self.builder, self.edition)
 
+        self.name = lookup
+
         base = self._raw[lookup]
 
         for i in ['excluded', 'tags', 'languages']:
@@ -88,19 +109,55 @@ class SphinxConfig(RecursiveConfigurationBase):
         logger.debug(m.format(language, builder, edition))
 
     @property
-    def build_output(self):
-        if 'edition' in self.conf.project and self.conf.project.edition != self.conf.project.name:
-            dirname = hyph_concat(self.builder, self.edition)
+    def name(self):
+        if 'name' in self.state:
+            return self.state['builder']
         else:
-            dirname = self.builder
+            return self.builder
 
-        path = os.path.join(self.conf.paths.projectroot, self.conf.paths.branch_output, dirname)
+    @name.setter
+    def name(self, value):
+        self.state['name'] = value
+
+    @property
+    def build_output(self):
+        path = resolve_builder_path(self.builder, self.edition, self.language, self.conf)
 
         if 'build_output' not in self.state:
             self.state['build_output'] = path
 
         return path
 
+    @build_output.setter
+    def build_output(self, value):
+        if 'build_output' not in self.state:
+            self.state['build_output'] = value
+
+    @property
+    def language(self):
+        if 'language' not in self.state:
+            return 'en'
+        else:
+            return self.state['language']
+
+    @language.setter
+    def language(self, value):
+        self.state['language'] = value
+
+    @property
+    def edition(self):
+        if 'edition' in self.state:
+            return self.state['edition']
+        else:
+            if 'edition' in self.conf.project and self.conf.project.edition != self.conf.project.name:
+                return self.conf.project.edition
+            else:
+                return ''
+
+    @edition.setter
+    def edition(self, value):
+        self.state['edition'] = value
+
     @property
     def builder(self):
         return self.state['builder']
@@ -117,15 +174,15 @@ class SphinxConfig(RecursiveConfigurationBase):
         return self.state['tags']
 
     @property
-    def langauges(self):
-        return self.state['langauges']
+    def languages(self):
+        return self.state['languages']
 
     @builder.setter
     def builder(self, value):
-        if value in sphinx.builders.BUILTIN_BUILDERS:
+        if value in avalible_sphinx_builders():
             self.state['builder'] = value
         else:
-            raise Exception('{0} is not a valid sphinx builder'.format(value))
+            raise TypeError('{0} is not a valid sphinx builder'.format(value))
 
     @excluded.setter
     def excluded(self, value):
@@ -143,13 +200,13 @@ class SphinxConfig(RecursiveConfigurationBase):
         else:
             self.state['tags'] = value
 
-    @langauges.setter
-    def langauges(self, value):
+    @languages.setter
+    def languages(self, value):
         if not isinstance(value, list):
-            logger.error('langauges must be a list.')
+            logger.error('languages must be a list.')
             raise TypeError
         else:
-            self.state['langauges'] = value
+            self.state['languages'] = value
 
 
 #################### Rendering for Legacy Config ####################
